﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Runtime.Remoting;

namespace PicoScope.AutomationDemo.Automation
{
  /// <summary>
  /// Runs automation commands through Inter Process Communication
  /// </summary>
  public class IpcAutomation
  {
    private static readonly Lazy<IpcAutomation> Lazy = new Lazy<IpcAutomation>(() => new IpcAutomation());

    private IpcAutomation()
    {
    }

    public static IpcAutomation Instance
    {
      get { return Lazy.Value; }
    }

    public string RunCommand(string cmd)
    {
      bool success = false;

      try
      {
        IAutomation automation =
          (IAutomation) Activator.GetObject(typeof (IAutomation), "ipc://PicoScope/PicoScopeAutomation");

        if (cmd != null)
        {
          if (cmd.Contains("="))
          {
            string[] v = cmd.Split("=".ToCharArray(), StringSplitOptions.RemoveEmptyEntries);

            if (v.Length > 1)
              success = automation.Do(v[0].Trim(), v[1].Trim());
          }
          else if (cmd.Trim().EndsWith("?"))
          {
            string output;

            success = automation.Do(cmd.Replace("?", "").Trim(), out output);

            if (success)
              return output;
          }
          else
          {
            success = automation.Do(cmd.Trim());
          }
        }
      }
      catch (RemotingException)
      {
        throw new PicoScopeNowFoundException();
      }

      return success ? "OK" : "Error";
    }
  }
}